/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.appconfig.impl;

import java.util.ArrayList;
import java.util.List;

import org.tinygroup.appconfig.AppConfig;
import org.tinygroup.appconfig.AppConfigManager;
import org.tinygroup.appconfig.util.AppConfigUtil;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.xmlparser.node.XmlNode;
import org.tinygroup.xmlparser.parser.XmlStringParser;

/**
 * 
 * 功能说明: 应用程序配置管理接口的默认实现，完成管理各个应用处理器的配置信息。配置详细信息定义在application.xml文件中。
 * 根节点为application
 * <p>
 * 系统版本: v1.0<br>
 * 开发人员: renhui <br>
 * 开发时间: 2013-2-22 <br>
 * 功能描述: 写明作用，调用方式，使用场景，以及特殊情况<br>
 */
public class AppConfigManagerImpl implements AppConfigManager {
	private static Logger logger = LoggerFactory
			.getLogger(AppConfigManagerImpl.class);
	private XmlNode configurationXmlNode = null;
	// 保存各个应用处理器配置信息列表
	private List<AppConfig> appConfigList = new ArrayList<AppConfig>();

	public AppConfigManagerImpl() {
	}

	/**
	 * 读取application.xml加载配置信息，设置配置信息的根节点
	 */
	public void loadConfig(String content) {
		configurationXmlNode = new XmlStringParser().parse(content).getRoot();
	}

	public void distributeConfig() {
		for (AppConfig config : appConfigList) {
			applyConfig(config);
		}
	}

	public void subscribeConfig(AppConfig appConfig) {
		appConfigList.add(appConfig);
		applyConfig(appConfig);
	}

	public void unsubscribeConfig(AppConfig appConfig) {
		appConfigList.remove(appConfig);
	}

	/**
	 * 为各个应用处理器设置自己的配置信息
	 */
	public void applyConfig(AppConfig appConfig) {
		AppConfigUtil.config(this, appConfig);
	}

	public String getNodeName() {
		return APPLICATION_ROOTNODE_NAME;
	}

	public void setConfiguration(XmlNode xmlNode) {
		configurationXmlNode = xmlNode;

	}

	public XmlNode getConfiguration() {
		return configurationXmlNode;
	}

}
