/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.appconfig.util;

import java.util.List;

import org.tinygroup.appconfig.AppConfig;

/**
 * 应用配置工具类，用于把父对象中的配置参数应用到子对象中。
 * @author luoguo
 *
 */
public final class AppConfigUtil {
	private AppConfigUtil() {
	}

	/**
	 * 如果儿子当中需要配置信息，则从父亲处获取配置给儿子
	 * @param father
	 * @param son
	 */
	public static void config(AppConfig father, AppConfig son) {
		if (son.getNodeName() != null && father.getConfiguration() != null) {
			son.setConfiguration(father.getConfiguration().getSubNode(
					son.getNodeName()));
		}
	}

	/**
	 * 如果有多个儿子需要配置信息，是从父亲处获取配置并分发给儿子们
	 * @param father
	 * @param sons
	 */
	public static <T extends AppConfig> void config(AppConfig father,
			List<T> sons) {
		if (sons != null && father.getConfiguration() != null) {
			for (AppConfig son : sons) {
				config(father, son);
			}
		}
	}
}
